Aggiornare un server SFTP

Puoi aggiornare gli utenti autorizzati a connettersi a un server Cloud FTP aggiornando la configurazione di accesso del server. Puoi anche aggiornare i metadati, ad esempio il nome visualizzato del server.

Una volta creato un server, non puoi modificarne il tipo (esterno o interno).

Ruoli obbligatori

Per ottenere l'autorizzazione necessaria per aggiornare un server SFTP, chiedi all'amministratore di concederti il ruolo IAM Cloud FTP Admin (roles/ftp.admin) nel progetto. Per saperne di più sulla concessione dei ruoli, consulta Gestisci l'accesso a progetti, cartelle e organizzazioni.

Questo ruolo predefinito contiene l' ftp.servers.update autorizzazione, necessaria per aggiornare un server SFTP.

Potresti anche ottenere questa autorizzazione con ruoli personalizzati o altri ruoli predefiniti.

Aggiornare l'accesso per un server esterno

gcloud

Per aggiornare la configurazione di accesso per un server esterno, esegui il gcloud alpha storage ftp servers update comando. Fornisci il flag --allowed-cidr-blocks.

Prima di utilizzare i dati dei comandi riportati di seguito, effettua le seguenti sostituzioni:

  • SERVER_ID: l'ID del server.
  • LOCATION_ID: la località del server, ad esempio us-west1.
  • CIDR_BLOCK: un blocco CIDR autorizzato ad accedere al server. Ad esempio, 192.0.2.0/24. Devi fornire almeno un valore e puoi fornire un massimo di 500 blocchi CIDR in un elenco separato da virgole. Per consentire le connessioni da tutti gli indirizzi IP, utilizza 0.0.0.0/0.

Esegui questo comando:

Linux, macOS o Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --allowed-cidr-blocks=CIDR_BLOCK
L'aggiornamento del server richiede alcuni secondi.

REST

Per aggiornare la configurazione di accesso per un server esterno, utilizza il servers.patch metodo. Nel parametro di query updateMask, fornisci il campo externalConfig.

Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:

  • PROJECT_ID: l' Google Cloud ID progetto del server.
  • LOCATION_ID: la località del server, ad esempio us-west1.
  • SERVER_ID: l'ID del server.
  • CIDR_BLOCK: un blocco CIDR autorizzato ad accedere al server. Ad esempio, 192.0.2.0/24. Devi fornire almeno un valore e puoi fornire un massimo di 500 blocchi CIDR . Per consentire le connessioni da tutti gli indirizzi IP, utilizza 0.0.0.0/0.

Metodo HTTP e URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=externalConfig

Corpo JSON della richiesta:

{
  "externalConfig": {
    "allowedCidrBlocks": [
      "CIDR_BLOCK"
    ]
  }
}

Per inviare la richiesta, espandi una di queste opzioni:

La risposta identifica un' operazione a lunga esecuzione. L'aggiornamento del server richiede alcuni secondi.

Aggiornare l'accesso per un server interno

gcloud

Per aggiornare la configurazione di accesso per un server interno, esegui il gcloud alpha storage ftp servers update comando. Fornisci il flag --consumer-accept-list e, facoltativamente, il flag --consumer-reject-list.

Prima di utilizzare i dati dei comandi riportati di seguito, effettua le seguenti sostituzioni:

  • SERVER_ID: l'ID del server.
  • LOCATION_ID: la località del server, ad esempio us-west1.
  • PROJECT_TO_ALLOW: l'ID progetto o il numero di un progetto consumer autorizzato a connettersi al server utilizzando Private Service Connect. Ad esempio, example-allowed-project. Devi specificare almeno un progetto.

    Puoi consentire un massimo di 500 progetti. Fornisci più progetti e i rispettivi limiti di connessione in un elenco separato da virgole. Ad esempio, --consumer-accept-list=projectA=20,projectB=15.

  • CONNECTION_LIMIT: il numero massimo di endpoint Private Service Connect che possono essere creati nel progetto consumer. Il valore deve essere compreso tra 1 e 250 endpoint.
  • (Facoltativo) PROJECT_TO_REJECT: l'ID progetto o il numero di un progetto consumer a cui è vietato connettersi al server. Ad esempio, example-rejected-project. I progetti in questo elenco non possono accedere al server anche se sono inclusi nell'elenco dei progetti consentiti.

    Puoi rifiutare un massimo di 64 progetti. Fornisci più progetti in un elenco separato da virgole.

    Se non vuoi rifiutare esplicitamente alcun progetto, ometti il --consumer-reject-list flag.

Esegui questo comando:

Linux, macOS o Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT \
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT `
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT ^
    --consumer-reject-list=PROJECT_TO_REJECT
L'aggiornamento del server richiede alcuni secondi.

REST

Per aggiornare la configurazione di accesso per un server interno, utilizza il servers.patch metodo. Nel parametro di query updateMask, fornisci il campo internalConfig.

Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:

  • PROJECT_ID: l' Google Cloud ID progetto del server.
  • LOCATION_ID: la località del server, ad esempio us-west1.
  • SERVER_ID: l'ID del server.
  • PROJECT_TO_ALLOW: l'ID progetto o il numero di un progetto consumer autorizzato a connettersi al server utilizzando Private Service Connect. Ad esempio, example-allowed-project. Devi specificare almeno un progetto.

    Puoi consentire un massimo di 500 progetti.

  • CONNECTION_LIMIT: il numero massimo di endpoint Private Service Connect che possono essere creati nel progetto consumer. Il valore deve essere compreso tra 1 e 250 endpoint.
  • (Facoltativo) PROJECT_TO_REJECT: l'ID progetto o il numero di un progetto consumer a cui è vietato connettersi al server. Ad esempio, example-rejected-project. I progetti in questo elenco non possono accedere al server anche se sono inclusi nell'elenco dei progetti consentiti.

    Puoi rifiutare un massimo di 64 progetti.

    Se non vuoi rifiutare esplicitamente alcun progetto, ometti l' consumerRejectList oggetto.

Metodo HTTP e URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=internalConfig

Corpo JSON della richiesta:

{
  "internalConfig": {
    "consumerAcceptList": [
      {
        "project": "projects/PROJECT_TO_ALLOW",
        "connectionLimit": CONNECTION_LIMIT
      }
    ],
    "consumerRejectList": [
      {
        "project": "projects/PROJECT_TO_REJECT"
      }
    ]
  }
}

Per inviare la richiesta, espandi una di queste opzioni:

La risposta identifica un' operazione a lunga esecuzione. L'aggiornamento del server richiede alcuni secondi.

Aggiornare il nome visualizzato di un server

gcloud

Per aggiornare i metadati, ad esempio il nome visualizzato di un server SFTP, esegui il gcloud alpha storage ftp servers update comando.

Prima di utilizzare i dati dei comandi riportati di seguito, effettua le seguenti sostituzioni:

  • SERVER_ID: l'ID del server.
  • LOCATION_ID: la località del server, ad esempio us-west1.
  • DISPLAY_NAME: un nome visualizzato per il server.

Esegui questo comando:

Linux, macOS o Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --display-name="DISPLAY_NAME"

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --display-name="DISPLAY_NAME"

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --display-name="DISPLAY_NAME"
L'aggiornamento del server richiede alcuni secondi.

REST

Per aggiornare i metadati, ad esempio il nome visualizzato di un server SFTP, utilizza il servers.patch metodo. Nel parametro di query updateMask, fornisci un elenco separato da virgole dei campi da aggiornare. Nel corpo della richiesta, fornisci un oggetto JSON con i valori da impostare.

Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:

  • PROJECT_ID: l' Google Cloud ID progetto del server.
  • LOCATION_ID: la località del server, ad esempio us-west1.
  • SERVER_ID: l'ID del server.
  • FIELDS_TO_UPDATE: un elenco separato da virgole dei campi da aggiornare, relativi alla risorsa server. Ad esempio, per aggiornare il nome visualizzato, fornisci il parametro di query updateMask=displayName.
  • DISPLAY_NAME: un nome visualizzato per il server.

Metodo HTTP e URL:

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=FIELDS_TO_UPDATE

Corpo JSON della richiesta:

{
  "displayName": "DISPLAY_NAME"
}

Per inviare la richiesta, espandi una di queste opzioni:

La risposta identifica un' operazione a lunga esecuzione. L'aggiornamento del server richiede alcuni secondi.